@@ -195,13 +195,14 @@ def _start_server(urlhandler, hostname, port):
 
         def stop(self):
             """Stop the server and this thread nicely"""
-            self.docserver.quit = True
-            self.join()
-            # explicitly break a reference cycle: DocServer.callback
-            # has indirectly a reference to ServerThread.
-            self.docserver = None
-            self.serving = False
-            self.url = None
+            if self.docserver != None:
+                self.docserver.quit = True
+                self.join()
+                # explicitly break a reference cycle: DocServer.callback
+                # has indirectly a reference to ServerThread.
+                self.docserver = None
+                self.serving = False
+                self.url = None
 
     thread = ServerThread(urlhandler, hostname, port)
     thread.start()
